<#  
.SYNOPSIS  
	Uploads multiple LPE firmware updates to all available pools.

.DESCRIPTION  
	Uploades Lync Phone Edition device firmware to all pools. It supports uploading firmware for multiple device models and multiple pools

.NOTES  
  Version      				: 1.0
  Rights Required			: Local admin on server
  										: ExecutionPolicy of RemoteSigned or Unrestricted
  Lync Version				: 2010 (tested on CU 6)
  Author       				: Pat Richard, Exchange MVP
  Email/Blog/Twitter	: pat@innervation.com 	http://www.ehloworld.com @patrichard
  Dedicated Blog			: http://www.ehloworld.com/1217 
  Disclaimer   				: You running this script means you won't blame me if this breaks your stuff.
  Info Stolen from 		: 
	Acknowledgements		: Kevin Peters for some original code examples

.EXAMPLE
	New-CsFirmware
	
	Details
	=======
	Will prompt for a parent folder containing any firmware files, including in child folders, and will upload them to all pools that it finds.

.EXAMPLE
	New-CsFirmware -FilesPath [path to parent folder]
	
	Details
	=======
	Will upload firmware update files within the parent folder and any child folder to all pools that it finds.

.INPUTS
	None. You cannot pipe objects to this script.

#Requires -Version 2.0
#>

[CmdletBinding(SupportsShouldProcess = $True)]
param(
	[Parameter(ValueFromPipeline = $True, ValueFromPipelineByPropertyName = $True, Mandatory = $False)]
	[string]$FilesPath,
	[Parameter(ValueFromPipeline = $True, ValueFromPipelineByPropertyName = $True, Mandatory = $False)]
	[ValidateNotNullOrEmpty()]
	[string]$LogsPath = ".\Logs"
)

function Get-Folder {  
	[CmdletBinding(SupportsShouldProcess = $True)]
	param(
		[Parameter(ValueFromPipeline = $False, ValueFromPipelineByPropertyName = $True, Mandatory = $False)]
		[ValidateNotNullOrEmpty()]
		[string]$message = "Select the desired folder",
		[Parameter(ValueFromPipeline = $False, ValueFromPipelineByPropertyName = $False, Mandatory = $False)]
		[int]$path = 0
	)
  [Object]$FolderObject = New-Object -ComObject Shell.Application   
  $folder = $FolderObject.BrowseForFolder(0, $message, 0, $path)  
  if ($folder -ne $null) {  
		# $folder.self.Path  
  }else{
  	Write-Host "No folder specified"
  }
} # end function Get-Folder

function New-CsFirmware	{
	if (!(Test-Path $LogsPath)){
		New-Item $LogsPath -type Directory | Out-Null
	}
	Import-Module Lync
	$FEPools = Get-CSService -UserServer
	if (!$FilesPath){
		Get-Folder "Select the folder that contains the firmware files"
	}
	[object]$files = Get-ChildItem $FilesPath -Recurse | ? {$_.name -match "ucupdates.cab"}
	if ($Files -and $FEPools){
		ForEach ($File in $Files){
			ForEach ($FEPool in $FEPools) {
				[string] $pool = "service:WebServer:"+$FEPool.PoolFQDN
				Import-CsDeviceUpdate -Identity $pool -FileName $file.versioninfo.filename -Verbose
			}
		}	
	}
} # end function New-CsFirmware

[string] $TranscriptName = "FirmwareUploader" + (Get-Date -Format s).Replace(":","-") +".txt" 
Start-Transcript $LogsPath\$TranscriptName | Out-Null

New-CsFirmware	

Stop-Transcript	| Out-Null